"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.field_mask_pb2
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import yandex.cloud.operation.operation_pb2
import yandex.cloud.organizationmanager.v1.organization_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class GetOrganizationRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ORGANIZATION_ID_FIELD_NUMBER: builtins.int
    organization_id: builtins.str
    """ID of the Organization resource to return.
    To get the organization ID, use a [OrganizationService.List] request.
    """
    def __init__(
        self,
        *,
        organization_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["organization_id", b"organization_id"]) -> None: ...

global___GetOrganizationRequest = GetOrganizationRequest

@typing.final
class ListOrganizationsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    page_size: builtins.int
    """The maximum number of results per page to return. If the number of available
    results is larger than [page_size],
    the service returns a [ListOrganizationsResponse.next_page_token]
    that can be used to get the next page of results in subsequent list requests.
    Default value: 100.
    """
    page_token: builtins.str
    """Page token. Set [page_token]
    to the [ListOrganizationsResponse.next_page_token]
    returned by a previous list request to get the next page of results.
    """
    filter: builtins.str
    """A filter expression that filters resources listed in the response.
    The expression must specify:
    1. The field name. Currently you can use filtering only on the [Organization.name] field.
    2. An `=` operator.
    3. The value in double quotes (`"`). Must be 3-63 characters long and match the regular expression `[a-z][-a-z0-9]{1,61}[a-z0-9]`.
    """
    def __init__(
        self,
        *,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
        filter: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["filter", b"filter", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListOrganizationsRequest = ListOrganizationsRequest

@typing.final
class ListOrganizationsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ORGANIZATIONS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """This token allows you to get the next page of results for list requests. If the number of results
    is larger than [ListOrganizationsRequest.page_size], use
    the [next_page_token] as the value
    for the [ListOrganizationsRequest.page_token] query parameter
    in the next list request. Each subsequent list request will have its own
    [next_page_token] to continue paging through the results.
    """
    @property
    def organizations(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.organizationmanager.v1.organization_pb2.Organization]:
        """List of Organization resources."""

    def __init__(
        self,
        *,
        organizations: collections.abc.Iterable[yandex.cloud.organizationmanager.v1.organization_pb2.Organization] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["next_page_token", b"next_page_token", "organizations", b"organizations"]) -> None: ...

global___ListOrganizationsResponse = ListOrganizationsResponse

@typing.final
class UpdateOrganizationRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    ORGANIZATION_ID_FIELD_NUMBER: builtins.int
    UPDATE_MASK_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    organization_id: builtins.str
    """ID of the organization to update.
    To get the organization ID, use a [OrganizationService.List] request.
    """
    name: builtins.str
    """Name of the organization."""
    description: builtins.str
    """Description of the organization."""
    title: builtins.str
    """Display name of the organization."""
    @property
    def update_mask(self) -> google.protobuf.field_mask_pb2.FieldMask:
        """Field mask that specifies which fields of the organization are going to be updated."""

    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Resource labels as `` key:value `` pairs."""

    def __init__(
        self,
        *,
        organization_id: builtins.str = ...,
        update_mask: google.protobuf.field_mask_pb2.FieldMask | None = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        title: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["update_mask", b"update_mask"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["description", b"description", "labels", b"labels", "name", b"name", "organization_id", b"organization_id", "title", b"title", "update_mask", b"update_mask"]) -> None: ...

global___UpdateOrganizationRequest = UpdateOrganizationRequest

@typing.final
class UpdateOrganizationMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ORGANIZATION_ID_FIELD_NUMBER: builtins.int
    organization_id: builtins.str
    """ID of the organization that is being updated."""
    def __init__(
        self,
        *,
        organization_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["organization_id", b"organization_id"]) -> None: ...

global___UpdateOrganizationMetadata = UpdateOrganizationMetadata

@typing.final
class ListOrganizationOperationsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ORGANIZATION_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    organization_id: builtins.str
    """ID of the Organization resource to list operations for."""
    page_size: builtins.int
    """The maximum number of results per page to return. If the number of available
    results is larger than [page_size], the service returns a [ListOrganizationOperationsResponse.next_page_token]
    that can be used to get the next page of results in subsequent list requests.
    Acceptable values are 0 to 1000, inclusive. Default value: 100.
    """
    page_token: builtins.str
    """Page token. Set [page_token]
    to the [ListOrganizationOperationsResponse.next_page_token]
    returned by a previous list request to get the next page of results.
    """
    def __init__(
        self,
        *,
        organization_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["organization_id", b"organization_id", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListOrganizationOperationsRequest = ListOrganizationOperationsRequest

@typing.final
class ListOrganizationOperationsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OPERATIONS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """This token allows you to get the next page of results for list requests. If the number of results
    is larger than [ListOrganizationOperationsRequest.page_size], use the [next_page_token] as the value
    for the [ListOrganizationOperationsRequest.page_token] query parameter in the next list request.
    Each subsequent list request will have its own [next_page_token] to continue paging through the results.
    """
    @property
    def operations(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.operation.operation_pb2.Operation]:
        """List of operations for the specified organization."""

    def __init__(
        self,
        *,
        operations: collections.abc.Iterable[yandex.cloud.operation.operation_pb2.Operation] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["next_page_token", b"next_page_token", "operations", b"operations"]) -> None: ...

global___ListOrganizationOperationsResponse = ListOrganizationOperationsResponse



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class Thresholds(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _ShowMode:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _ShowModeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Thresholds._ShowMode.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        SHOW_MODE_UNSPECIFIED: Thresholds._ShowMode.ValueType  # 0
        SHOW_MODE_CONSTANT_LINE: Thresholds._ShowMode.ValueType  # 1

    class ShowMode(_ShowMode, metaclass=_ShowModeEnumTypeWrapper): ...
    SHOW_MODE_UNSPECIFIED: Thresholds.ShowMode.ValueType  # 0
    SHOW_MODE_CONSTANT_LINE: Thresholds.ShowMode.ValueType  # 1

    @typing.final
    class Item(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        COLOR_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        color: builtins.str
        """Color in hexadecimal format"""
        value: builtins.float
        """Threshold value"""
        def __init__(
            self,
            *,
            color: builtins.str = ...,
            value: builtins.float | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["_value", b"_value", "value", b"value"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["_value", b"_value", "color", b"color", "value", b"value"]) -> None: ...
        def WhichOneof(self, oneof_group: typing.Literal["_value", b"_value"]) -> typing.Literal["value"] | None: ...

    ITEMS_FIELD_NUMBER: builtins.int
    SHOW_MODE_FIELD_NUMBER: builtins.int
    show_mode: global___Thresholds.ShowMode.ValueType
    """Thresholds visualisation mode"""
    @property
    def items(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Thresholds.Item]:
        """Thresholds"""

    def __init__(
        self,
        *,
        items: collections.abc.Iterable[global___Thresholds.Item] | None = ...,
        show_mode: global___Thresholds.ShowMode.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["items", b"items", "show_mode", b"show_mode"]) -> None: ...

global___Thresholds = Thresholds



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.timestamp_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class StylePreset(google.protobuf.message.Message):
    """Entity representing a collection of visual styling settings for content presentation.
    Style presets define the appearance of players, widgets, and other UI elements
    to ensure consistent branding and user experience.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _WidgetLocation:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _WidgetLocationEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[StylePreset._WidgetLocation.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        WIDGET_LOCATION_UNSPECIFIED: StylePreset._WidgetLocation.ValueType  # 0
        """The widget location is not specified."""
        RIGHT: StylePreset._WidgetLocation.ValueType  # 1
        """Position the widget to the right of the player."""
        BOTTOM: StylePreset._WidgetLocation.ValueType  # 2
        """Position the widget below the player."""

    class WidgetLocation(_WidgetLocation, metaclass=_WidgetLocationEnumTypeWrapper):
        """Widget position relative to the player."""

    WIDGET_LOCATION_UNSPECIFIED: StylePreset.WidgetLocation.ValueType  # 0
    """The widget location is not specified."""
    RIGHT: StylePreset.WidgetLocation.ValueType  # 1
    """Position the widget to the right of the player."""
    BOTTOM: StylePreset.WidgetLocation.ValueType  # 2
    """Position the widget below the player."""

    ID_FIELD_NUMBER: builtins.int
    CHANNEL_ID_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    BACKGROUND_COLOR_FIELD_NUMBER: builtins.int
    WIDGET_TEXT_COLOR_PRIMARY_FIELD_NUMBER: builtins.int
    WIDGET_TEXT_COLOR_SECONDARY_FIELD_NUMBER: builtins.int
    WIDGET_ACCENT_COLOR_FIELD_NUMBER: builtins.int
    WIDGET_BLOCK_GAP_FIELD_NUMBER: builtins.int
    WIDGET_BLOCK_SEPARATOR_COLOR_FIELD_NUMBER: builtins.int
    PLAYER_BORDER_RADIUS_FIELD_NUMBER: builtins.int
    PLAYER_COLOR_FIELD_NUMBER: builtins.int
    PLAYLIST_SELECTED_ITEM_BACKGROUND_COLOR_FIELD_NUMBER: builtins.int
    PLAYLIST_ITEM_BORDER_RADIUS_FIELD_NUMBER: builtins.int
    PLAYLIST_ITEM_GAP_FIELD_NUMBER: builtins.int
    PLAYLIST_LOCATION_FIELD_NUMBER: builtins.int
    RIGHT_WIDGETS_FIELD_NUMBER: builtins.int
    BOTTOM_WIDGETS_FIELD_NUMBER: builtins.int
    CREATED_AT_FIELD_NUMBER: builtins.int
    UPDATED_AT_FIELD_NUMBER: builtins.int
    id: builtins.str
    """Unique identifier of the style preset."""
    channel_id: builtins.str
    """Identifier of the channel where this style preset is created and managed."""
    title: builtins.str
    """Display name of the style preset shown in interfaces."""
    background_color: builtins.str
    """Background color for the player page in hexadecimal format (e.g., "#FFFFFF")."""
    widget_text_color_primary: builtins.str
    """Primary text color for widgets in hexadecimal format."""
    widget_text_color_secondary: builtins.str
    """Secondary text color for widgets in hexadecimal format."""
    widget_accent_color: builtins.str
    """Accent color for interactive elements in widgets in hexadecimal format."""
    widget_block_gap: builtins.int
    """Vertical spacing between widget blocks in pixels."""
    widget_block_separator_color: builtins.str
    """Color of separator lines between widget blocks in hexadecimal format."""
    player_border_radius: builtins.int
    """Corner radius of the player container in pixels."""
    player_color: builtins.str
    """Primary color for player controls in hexadecimal format."""
    playlist_selected_item_background_color: builtins.str
    """Background color for the currently selected item in playlists in hexadecimal format."""
    playlist_item_border_radius: builtins.int
    """Corner radius of playlist items in pixels."""
    playlist_item_gap: builtins.int
    """Spacing between playlist items in pixels."""
    playlist_location: global___StylePreset.WidgetLocation.ValueType
    """Position of the playlist widget relative to the player."""
    @property
    def right_widgets(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Widget]:
        """List of widgets to display to the right of the player."""

    @property
    def bottom_widgets(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Widget]:
        """List of widgets to display below the player."""

    @property
    def created_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Timestamp when the style preset was initially created in the system."""

    @property
    def updated_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Timestamp of the last modification to the style preset or its metadata."""

    def __init__(
        self,
        *,
        id: builtins.str = ...,
        channel_id: builtins.str = ...,
        title: builtins.str = ...,
        background_color: builtins.str = ...,
        widget_text_color_primary: builtins.str = ...,
        widget_text_color_secondary: builtins.str = ...,
        widget_accent_color: builtins.str = ...,
        widget_block_gap: builtins.int = ...,
        widget_block_separator_color: builtins.str = ...,
        player_border_radius: builtins.int = ...,
        player_color: builtins.str = ...,
        playlist_selected_item_background_color: builtins.str = ...,
        playlist_item_border_radius: builtins.int = ...,
        playlist_item_gap: builtins.int = ...,
        playlist_location: global___StylePreset.WidgetLocation.ValueType = ...,
        right_widgets: collections.abc.Iterable[global___Widget] | None = ...,
        bottom_widgets: collections.abc.Iterable[global___Widget] | None = ...,
        created_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        updated_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["created_at", b"created_at", "updated_at", b"updated_at"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["background_color", b"background_color", "bottom_widgets", b"bottom_widgets", "channel_id", b"channel_id", "created_at", b"created_at", "id", b"id", "player_border_radius", b"player_border_radius", "player_color", b"player_color", "playlist_item_border_radius", b"playlist_item_border_radius", "playlist_item_gap", b"playlist_item_gap", "playlist_location", b"playlist_location", "playlist_selected_item_background_color", b"playlist_selected_item_background_color", "right_widgets", b"right_widgets", "title", b"title", "updated_at", b"updated_at", "widget_accent_color", b"widget_accent_color", "widget_block_gap", b"widget_block_gap", "widget_block_separator_color", b"widget_block_separator_color", "widget_text_color_primary", b"widget_text_color_primary", "widget_text_color_secondary", b"widget_text_color_secondary"]) -> None: ...

global___StylePreset = StylePreset

@typing.final
class Widget(google.protobuf.message.Message):
    """Represents a UI component that displays additional content or functionality.
    Widgets can be positioned in different locations around the player.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class Summarization(google.protobuf.message.Message):
        """Widget that presents an automatically generated summary of the video content.
        This helps viewers quickly understand the main points without watching the entire video.
        """

        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        def __init__(
            self,
        ) -> None: ...

    @typing.final
    class Description(google.protobuf.message.Message):
        """Widget that displays the full description text for the video.
        This can include details about the content, creators, and other relevant information.
        """

        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        def __init__(
            self,
        ) -> None: ...

    SUMMARIZATION_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    @property
    def summarization(self) -> global___Widget.Summarization:
        """Widget that displays video content summarization."""

    @property
    def description(self) -> global___Widget.Description:
        """Widget that displays detailed video description."""

    def __init__(
        self,
        *,
        summarization: global___Widget.Summarization | None = ...,
        description: global___Widget.Description | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["description", b"description", "summarization", b"summarization", "widget", b"widget"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["description", b"description", "summarization", b"summarization", "widget", b"widget"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["widget", b"widget"]) -> typing.Literal["summarization", "description"] | None: ...

global___Widget = Widget



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/containerregistry/v1/image.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/containerregistry/v1/image.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yandex.cloud.containerregistry.v1 import blob_pb2 as yandex_dot_cloud_dot_containerregistry_dot_v1_dot_blob__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n-yandex/cloud/containerregistry/v1/image.proto\x12!yandex.cloud.containerregistry.v1\x1a,yandex/cloud/containerregistry/v1/blob.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xfa\x01\n\x05Image\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0e\n\x06\x64igest\x18\x03 \x01(\t\x12\x17\n\x0f\x63ompressed_size\x18\x04 \x01(\x03\x12\x37\n\x06\x63onfig\x18\x05 \x01(\x0b\x32\'.yandex.cloud.containerregistry.v1.Blob\x12\x37\n\x06layers\x18\x06 \x03(\x0b\x32\'.yandex.cloud.containerregistry.v1.Blob\x12\x0c\n\x04tags\x18\x07 \x03(\t\x12.\n\ncreated_at\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x80\x01\n%yandex.cloud.api.containerregistry.v1ZWgithub.com/yandex-cloud/go-genproto/yandex/cloud/containerregistry/v1;containerregistryb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.containerregistry.v1.image_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n%yandex.cloud.api.containerregistry.v1ZWgithub.com/yandex-cloud/go-genproto/yandex/cloud/containerregistry/v1;containerregistry'
  _globals['_IMAGE']._serialized_start=164
  _globals['_IMAGE']._serialized_end=414
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/mdb/mysql/v1/database.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/mdb/mysql/v1/database.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(yandex/cloud/mdb/mysql/v1/database.proto\x12\x19yandex.cloud.mdb.mysql.v1\x1a\x1dyandex/cloud/validation.proto\",\n\x08\x44\x61tabase\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x12\n\ncluster_id\x18\x02 \x01(\t\"<\n\x0c\x44\x61tabaseSpec\x12,\n\x04name\x18\x01 \x01(\tB\x1e\xe8\xc7\x31\x01\xf2\xc7\x31\x0e[a-zA-Z0-9_-]*\x8a\xc8\x31\x04<=63Bd\n\x1dyandex.cloud.api.mdb.mysql.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/mysql/v1;mysqlb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.mdb.mysql.v1.database_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\035yandex.cloud.api.mdb.mysql.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/mysql/v1;mysql'
  _globals['_DATABASESPEC'].fields_by_name['name']._loaded_options = None
  _globals['_DATABASESPEC'].fields_by_name['name']._serialized_options = b'\350\3071\001\362\3071\016[a-zA-Z0-9_-]*\212\3101\004<=63'
  _globals['_DATABASE']._serialized_start=102
  _globals['_DATABASE']._serialized_end=146
  _globals['_DATABASESPEC']._serialized_start=148
  _globals['_DATABASESPEC']._serialized_end=208
# @@protoc_insertion_point(module_scope)



"""Main package for Yandex.Cloud SDK."""

# flake8: noqa
from yandexcloud._auth_fabric import set_up_yc_api_endpoint
from yandexcloud._backoff import (
    backoff_exponential_with_jitter,
    backoff_linear_with_jitter,
    default_backoff,
)
from yandexcloud._retry_interceptor import RetryInterceptor
from yandexcloud._retry_policy import RetryPolicy, ThrottlingMode
from yandexcloud._sdk import SDK

__version__ = "0.359.0"



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import collections.abc
import grpc
import grpc.aio
import typing
import yandex.cloud.datatransfer.v1.endpoint_pb2
import yandex.cloud.datatransfer.v1.endpoint_service_pb2
import yandex.cloud.operation.operation_pb2

_T = typing.TypeVar("_T")

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta): ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore[misc, type-arg]
    ...

class EndpointServiceStub:
    """A set of methods for managing [endpoints]({{ api-url-prefix
    }}/data-transfer/concepts/#endpoint).
    """

    def __init__(self, channel: typing.Union[grpc.Channel, grpc.aio.Channel]) -> None: ...
    Get: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.datatransfer.v1.endpoint_service_pb2.GetEndpointRequest,
        yandex.cloud.datatransfer.v1.endpoint_pb2.Endpoint,
    ]
    """Returns the specified endpoint.

    To get the list of all available endpoints, make a [List] request.
    """

    List: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.datatransfer.v1.endpoint_service_pb2.ListEndpointsRequest,
        yandex.cloud.datatransfer.v1.endpoint_service_pb2.ListEndpointsResponse,
    ]
    """Lists endpoints in the specified folder."""

    Create: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.datatransfer.v1.endpoint_service_pb2.CreateEndpointRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Creates an endpoint in the specified folder."""

    Update: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.datatransfer.v1.endpoint_service_pb2.UpdateEndpointRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates the specified endpoint."""

    Delete: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.datatransfer.v1.endpoint_service_pb2.DeleteEndpointRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deletes the specified endpoint."""

class EndpointServiceAsyncStub:
    """A set of methods for managing [endpoints]({{ api-url-prefix
    }}/data-transfer/concepts/#endpoint).
    """

    Get: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.datatransfer.v1.endpoint_service_pb2.GetEndpointRequest,
        yandex.cloud.datatransfer.v1.endpoint_pb2.Endpoint,
    ]
    """Returns the specified endpoint.

    To get the list of all available endpoints, make a [List] request.
    """

    List: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.datatransfer.v1.endpoint_service_pb2.ListEndpointsRequest,
        yandex.cloud.datatransfer.v1.endpoint_service_pb2.ListEndpointsResponse,
    ]
    """Lists endpoints in the specified folder."""

    Create: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.datatransfer.v1.endpoint_service_pb2.CreateEndpointRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Creates an endpoint in the specified folder."""

    Update: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.datatransfer.v1.endpoint_service_pb2.UpdateEndpointRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates the specified endpoint."""

    Delete: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.datatransfer.v1.endpoint_service_pb2.DeleteEndpointRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deletes the specified endpoint."""

class EndpointServiceServicer(metaclass=abc.ABCMeta):
    """A set of methods for managing [endpoints]({{ api-url-prefix
    }}/data-transfer/concepts/#endpoint).
    """

    @abc.abstractmethod
    def Get(
        self,
        request: yandex.cloud.datatransfer.v1.endpoint_service_pb2.GetEndpointRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.datatransfer.v1.endpoint_pb2.Endpoint, collections.abc.Awaitable[yandex.cloud.datatransfer.v1.endpoint_pb2.Endpoint]]:
        """Returns the specified endpoint.

        To get the list of all available endpoints, make a [List] request.
        """

    @abc.abstractmethod
    def List(
        self,
        request: yandex.cloud.datatransfer.v1.endpoint_service_pb2.ListEndpointsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.datatransfer.v1.endpoint_service_pb2.ListEndpointsResponse, collections.abc.Awaitable[yandex.cloud.datatransfer.v1.endpoint_service_pb2.ListEndpointsResponse]]:
        """Lists endpoints in the specified folder."""

    @abc.abstractmethod
    def Create(
        self,
        request: yandex.cloud.datatransfer.v1.endpoint_service_pb2.CreateEndpointRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Creates an endpoint in the specified folder."""

    @abc.abstractmethod
    def Update(
        self,
        request: yandex.cloud.datatransfer.v1.endpoint_service_pb2.UpdateEndpointRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Updates the specified endpoint."""

    @abc.abstractmethod
    def Delete(
        self,
        request: yandex.cloud.datatransfer.v1.endpoint_service_pb2.DeleteEndpointRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Deletes the specified endpoint."""

def add_EndpointServiceServicer_to_server(servicer: EndpointServiceServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/baremetal/v1alpha/image_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/baremetal/v1alpha/image_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.baremetal.v1alpha import image_pb2 as yandex_dot_cloud_dot_baremetal_dot_v1alpha_dot_image__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n2yandex/cloud/baremetal/v1alpha/image_service.proto\x12\x1eyandex.cloud.baremetal.v1alpha\x1a\x1cgoogle/api/annotations.proto\x1a google/protobuf/field_mask.proto\x1a yandex/cloud/api/operation.proto\x1a*yandex/cloud/baremetal/v1alpha/image.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\"=\n\x0fGetImageRequest\x12*\n\x08image_id\x18\x01 \x01(\tB\x18\xf2\xc7\x31\x0e[a-z][a-z0-9]*\x8a\xc8\x31\x02\x32\x30\"\x9e\x01\n\x11ListImagesRequest\x12/\n\tfolder_id\x18\x01 \x01(\tB\x1c\xf2\xc7\x31\x10[a-z][a-z0-9.-]*\x8a\xc8\x31\x04<=50\x12\x1c\n\tpage_size\x18\x64 \x01(\x03\x42\t\xfa\xc7\x31\x05<=100\x12\x12\n\npage_token\x18\x65 \x01(\t\x12\x10\n\x08order_by\x18\x66 \x01(\t\x12\x0e\n\x06\x66ilter\x18g \x01(\tJ\x04\x08\x02\x10\x64\"j\n\x12ListImagesResponse\x12\x35\n\x06images\x18\x01 \x03(\x0b\x32%.yandex.cloud.baremetal.v1alpha.Image\x12\x17\n\x0fnext_page_token\x18\x64 \x01(\tJ\x04\x08\x02\x10\x64\"\x84\x03\n\x12\x43reateImageRequest\x12/\n\tfolder_id\x18\x01 \x01(\tB\x1c\xf2\xc7\x31\x10[a-z][a-z0-9.-]*\x8a\xc8\x31\x04<=50\x12\x34\n\x04name\x18\x02 \x01(\tB&\xf2\xc7\x31\x1a[a-z]([-a-z0-9]*[a-z0-9])?\x8a\xc8\x31\x04\x32-63\x12\x1f\n\x0b\x64\x65scription\x18\x03 \x01(\tB\n\x8a\xc8\x31\x06<=1024\x12\x1b\n\x03uri\x18\x0b \x01(\tB\x0e\xe8\xc7\x31\x01\x8a\xc8\x31\x06<=1024\x12\x8c\x01\n\x06labels\x18\xc8\x01 \x03(\x0b\x32>.yandex.cloud.baremetal.v1alpha.CreateImageRequest.LabelsEntryB;\xf2\xc7\x31\x0b[-_0-9a-z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x18\x12\x10[a-z][-_0-9a-z]*\x1a\x04\x31-63\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01J\x04\x08\x04\x10\x0bJ\x05\x08\x0c\x10\xc8\x01\"\'\n\x13\x43reateImageMetadata\x12\x10\n\x08image_id\x18\x01 \x01(\t\"\x8d\x03\n\x12UpdateImageRequest\x12*\n\x08image_id\x18\x01 \x01(\tB\x18\xf2\xc7\x31\x0e[a-z][a-z0-9]*\x8a\xc8\x31\x02\x32\x30\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12\x34\n\x04name\x18\x03 \x01(\tB&\xf2\xc7\x31\x1a[a-z]([-a-z0-9]*[a-z0-9])?\x8a\xc8\x31\x04\x32-63\x12\x1f\n\x0b\x64\x65scription\x18\x04 \x01(\tB\n\x8a\xc8\x31\x06<=1024\x12\x8c\x01\n\x06labels\x18\xc8\x01 \x03(\x0b\x32>.yandex.cloud.baremetal.v1alpha.UpdateImageRequest.LabelsEntryB;\xf2\xc7\x31\x0b[-_0-9a-z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x18\x12\x10[a-z][-_0-9a-z]*\x1a\x04\x31-63\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01J\x05\x08\x05\x10\xc8\x01\"\'\n\x13UpdateImageMetadata\x12\x10\n\x08image_id\x18\x01 \x01(\t\"@\n\x12\x44\x65leteImageRequest\x12*\n\x08image_id\x18\x01 \x01(\tB\x18\xf2\xc7\x31\x0e[a-z][a-z0-9]*\x8a\xc8\x31\x02\x32\x30\"\'\n\x13\x44\x65leteImageMetadata\x12\x10\n\x08image_id\x18\x01 \x01(\t\"\x80\x01\n\x1aListImageOperationsRequest\x12*\n\x08image_id\x18\x01 \x01(\tB\x18\xf2\xc7\x31\x0e[a-z][a-z0-9]*\x8a\xc8\x31\x02\x32\x30\x12\x1c\n\tpage_size\x18\x64 \x01(\x03\x42\t\xfa\xc7\x31\x05<=100\x12\x12\n\npage_token\x18\x65 \x01(\tJ\x04\x08\x02\x10\x64\"s\n\x1bListImageOperationsResponse\x12\x35\n\noperations\x18\x01 \x03(\x0b\x32!.yandex.cloud.operation.Operation\x12\x17\n\x0fnext_page_token\x18\x64 \x01(\tJ\x04\x08\x02\x10\x64\x32\x8f\x08\n\x0cImageService\x12\x8b\x01\n\x03Get\x12/.yandex.cloud.baremetal.v1alpha.GetImageRequest\x1a%.yandex.cloud.baremetal.v1alpha.Image\",\x82\xd3\xe4\x93\x02&\x12$/baremetal/v1alpha/images/{image_id}\x12\x90\x01\n\x04List\x12\x31.yandex.cloud.baremetal.v1alpha.ListImagesRequest\x1a\x32.yandex.cloud.baremetal.v1alpha.ListImagesResponse\"!\x82\xd3\xe4\x93\x02\x1b\x12\x19/baremetal/v1alpha/images\x12\xa5\x01\n\x06\x43reate\x12\x32.yandex.cloud.baremetal.v1alpha.CreateImageRequest\x1a!.yandex.cloud.operation.Operation\"D\xb2\xd2*\x1c\n\x13\x43reateImageMetadata\x12\x05Image\x82\xd3\xe4\x93\x02\x1e\"\x19/baremetal/v1alpha/images:\x01*\x12\xb0\x01\n\x06Update\x12\x32.yandex.cloud.baremetal.v1alpha.UpdateImageRequest\x1a!.yandex.cloud.operation.Operation\"O\xb2\xd2*\x1c\n\x13UpdateImageMetadata\x12\x05Image\x82\xd3\xe4\x93\x02)2$/baremetal/v1alpha/images/{image_id}:\x01*\x12\xbd\x01\n\x06\x44\x65lete\x12\x32.yandex.cloud.baremetal.v1alpha.DeleteImageRequest\x1a!.yandex.cloud.operation.Operation\"\\\xb2\xd2*,\n\x13\x44\x65leteImageMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02&*$/baremetal/v1alpha/images/{image_id}\x12\xc2\x01\n\x0eListOperations\x12:.yandex.cloud.baremetal.v1alpha.ListImageOperationsRequest\x1a;.yandex.cloud.baremetal.v1alpha.ListImageOperationsResponse\"7\x82\xd3\xe4\x93\x02\x31\x12//baremetal/v1alpha/images/{image_id}/operationsBr\n\"yandex.cloud.api.baremetal.v1alphaZLgithub.com/yandex-cloud/go-genproto/yandex/cloud/baremetal/v1alpha;baremetalb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.baremetal.v1alpha.image_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\"yandex.cloud.api.baremetal.v1alphaZLgithub.com/yandex-cloud/go-genproto/yandex/cloud/baremetal/v1alpha;baremetal'
  _globals['_GETIMAGEREQUEST'].fields_by_name['image_id']._loaded_options = None
  _globals['_GETIMAGEREQUEST'].fields_by_name['image_id']._serialized_options = b'\362\3071\016[a-z][a-z0-9]*\212\3101\00220'
  _globals['_LISTIMAGESREQUEST'].fields_by_name['folder_id']._loaded_options = None
  _globals['_LISTIMAGESREQUEST'].fields_by_name['folder_id']._serialized_options = b'\362\3071\020[a-z][a-z0-9.-]*\212\3101\004<=50'
  _globals['_LISTIMAGESREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTIMAGESREQUEST'].fields_by_name['page_size']._serialized_options = b'\372\3071\005<=100'
  _globals['_CREATEIMAGEREQUEST_LABELSENTRY']._loaded_options = None
  _globals['_CREATEIMAGEREQUEST_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_CREATEIMAGEREQUEST'].fields_by_name['folder_id']._loaded_options = None
  _globals['_CREATEIMAGEREQUEST'].fields_by_name['folder_id']._serialized_options = b'\362\3071\020[a-z][a-z0-9.-]*\212\3101\004<=50'
  _globals['_CREATEIMAGEREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_CREATEIMAGEREQUEST'].fields_by_name['name']._serialized_options = b'\362\3071\032[a-z]([-a-z0-9]*[a-z0-9])?\212\3101\0042-63'
  _globals['_CREATEIMAGEREQUEST'].fields_by_name['description']._loaded_options = None
  _globals['_CREATEIMAGEREQUEST'].fields_by_name['description']._serialized_options = b'\212\3101\006<=1024'
  _globals['_CREATEIMAGEREQUEST'].fields_by_name['uri']._loaded_options = None
  _globals['_CREATEIMAGEREQUEST'].fields_by_name['uri']._serialized_options = b'\350\3071\001\212\3101\006<=1024'
  _globals['_CREATEIMAGEREQUEST'].fields_by_name['labels']._loaded_options = None
  _globals['_CREATEIMAGEREQUEST'].fields_by_name['labels']._serialized_options = b'\362\3071\013[-_0-9a-z]*\202\3101\004<=64\212\3101\004<=63\262\3101\030\022\020[a-z][-_0-9a-z]*\032\0041-63'
  _globals['_UPDATEIMAGEREQUEST_LABELSENTRY']._loaded_options = None
  _globals['_UPDATEIMAGEREQUEST_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_UPDATEIMAGEREQUEST'].fields_by_name['image_id']._loaded_options = None
  _globals['_UPDATEIMAGEREQUEST'].fields_by_name['image_id']._serialized_options = b'\362\3071\016[a-z][a-z0-9]*\212\3101\00220'
  _globals['_UPDATEIMAGEREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_UPDATEIMAGEREQUEST'].fields_by_name['name']._serialized_options = b'\362\3071\032[a-z]([-a-z0-9]*[a-z0-9])?\212\3101\0042-63'
  _globals['_UPDATEIMAGEREQUEST'].fields_by_name['description']._loaded_options = None
  _globals['_UPDATEIMAGEREQUEST'].fields_by_name['description']._serialized_options = b'\212\3101\006<=1024'
  _globals['_UPDATEIMAGEREQUEST'].fields_by_name['labels']._loaded_options = None
  _globals['_UPDATEIMAGEREQUEST'].fields_by_name['labels']._serialized_options = b'\362\3071\013[-_0-9a-z]*\202\3101\004<=64\212\3101\004<=63\262\3101\030\022\020[a-z][-_0-9a-z]*\032\0041-63'
  _globals['_DELETEIMAGEREQUEST'].fields_by_name['image_id']._loaded_options = None
  _globals['_DELETEIMAGEREQUEST'].fields_by_name['image_id']._serialized_options = b'\362\3071\016[a-z][a-z0-9]*\212\3101\00220'
  _globals['_LISTIMAGEOPERATIONSREQUEST'].fields_by_name['image_id']._loaded_options = None
  _globals['_LISTIMAGEOPERATIONSREQUEST'].fields_by_name['image_id']._serialized_options = b'\362\3071\016[a-z][a-z0-9]*\212\3101\00220'
  _globals['_LISTIMAGEOPERATIONSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTIMAGEOPERATIONSREQUEST'].fields_by_name['page_size']._serialized_options = b'\372\3071\005<=100'
  _globals['_IMAGESERVICE'].methods_by_name['Get']._loaded_options = None
  _globals['_IMAGESERVICE'].methods_by_name['Get']._serialized_options = b'\202\323\344\223\002&\022$/baremetal/v1alpha/images/{image_id}'
  _globals['_IMAGESERVICE'].methods_by_name['List']._loaded_options = None
  _globals['_IMAGESERVICE'].methods_by_name['List']._serialized_options = b'\202\323\344\223\002\033\022\031/baremetal/v1alpha/images'
  _globals['_IMAGESERVICE'].methods_by_name['Create']._loaded_options = None
  _globals['_IMAGESERVICE'].methods_by_name['Create']._serialized_options = b'\262\322*\034\n\023CreateImageMetadata\022\005Image\202\323\344\223\002\036\"\031/baremetal/v1alpha/images:\001*'
  _globals['_IMAGESERVICE'].methods_by_name['Update']._loaded_options = None
  _globals['_IMAGESERVICE'].methods_by_name['Update']._serialized_options = b'\262\322*\034\n\023UpdateImageMetadata\022\005Image\202\323\344\223\002)2$/baremetal/v1alpha/images/{image_id}:\001*'
  _globals['_IMAGESERVICE'].methods_by_name['Delete']._loaded_options = None
  _globals['_IMAGESERVICE'].methods_by_name['Delete']._serialized_options = b'\262\322*,\n\023DeleteImageMetadata\022\025google.protobuf.Empty\202\323\344\223\002&*$/baremetal/v1alpha/images/{image_id}'
  _globals['_IMAGESERVICE'].methods_by_name['ListOperations']._loaded_options = None
  _globals['_IMAGESERVICE'].methods_by_name['ListOperations']._serialized_options = b'\202\323\344\223\0021\022//baremetal/v1alpha/images/{image_id}/operations'
  _globals['_GETIMAGEREQUEST']._serialized_start=299
  _globals['_GETIMAGEREQUEST']._serialized_end=360
  _globals['_LISTIMAGESREQUEST']._serialized_start=363
  _globals['_LISTIMAGESREQUEST']._serialized_end=521
  _globals['_LISTIMAGESRESPONSE']._serialized_start=523
  _globals['_LISTIMAGESRESPONSE']._serialized_end=629
  _globals['_CREATEIMAGEREQUEST']._serialized_start=632
  _globals['_CREATEIMAGEREQUEST']._serialized_end=1020
  _globals['_CREATEIMAGEREQUEST_LABELSENTRY']._serialized_start=962
  _globals['_CREATEIMAGEREQUEST_LABELSENTRY']._serialized_end=1007
  _globals['_CREATEIMAGEMETADATA']._serialized_start=1022
  _globals['_CREATEIMAGEMETADATA']._serialized_end=1061
  _globals['_UPDATEIMAGEREQUEST']._serialized_start=1064
  _globals['_UPDATEIMAGEREQUEST']._serialized_end=1461
  _globals['_UPDATEIMAGEREQUEST_LABELSENTRY']._serialized_start=962
  _globals['_UPDATEIMAGEREQUEST_LABELSENTRY']._serialized_end=1007
  _globals['_UPDATEIMAGEMETADATA']._serialized_start=1463
  _globals['_UPDATEIMAGEMETADATA']._serialized_end=1502
  _globals['_DELETEIMAGEREQUEST']._serialized_start=1504
  _globals['_DELETEIMAGEREQUEST']._serialized_end=1568
  _globals['_DELETEIMAGEMETADATA']._serialized_start=1570
  _globals['_DELETEIMAGEMETADATA']._serialized_end=1609
  _globals['_LISTIMAGEOPERATIONSREQUEST']._serialized_start=1612
  _globals['_LISTIMAGEOPERATIONSREQUEST']._serialized_end=1740
  _globals['_LISTIMAGEOPERATIONSRESPONSE']._serialized_start=1742
  _globals['_LISTIMAGEOPERATIONSRESPONSE']._serialized_end=1857
  _globals['_IMAGESERVICE']._serialized_start=1860
  _globals['_IMAGESERVICE']._serialized_end=2899
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/cloudregistry/v1/artifact.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/cloudregistry/v1/artifact.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n,yandex/cloud/cloudregistry/v1/artifact.proto\x12\x1dyandex.cloud.cloudregistry.v1\x1a\x1fgoogle/protobuf/timestamp.proto\"\x9e\x03\n\x08\x41rtifact\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04path\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12:\n\x04kind\x18\x04 \x01(\x0e\x32,.yandex.cloud.cloudregistry.v1.Artifact.Kind\x12>\n\x06status\x18\x05 \x01(\x0e\x32..yandex.cloud.cloudregistry.v1.Artifact.Status\x12.\n\ncreated_at\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12/\n\x0bmodified_at\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"C\n\x04Kind\x12\x14\n\x10KIND_UNSPECIFIED\x10\x00\x12\n\n\x06\x46OLDER\x10\x01\x12\x0b\n\x07PACKAGE\x10\x02\x12\x0c\n\x08\x41RTIFACT\x10\x03\"H\n\x06Status\x12\x16\n\x12STATUS_UNSPECIFIED\x10\x00\x12\x0c\n\x08\x43REATING\x10\x01\x12\n\n\x06\x41\x43TIVE\x10\x02\x12\x0c\n\x08\x44\x45LETING\x10\x03\x42t\n!yandex.cloud.api.cloudregistry.v1ZOgithub.com/yandex-cloud/go-genproto/yandex/cloud/cloudregistry/v1;cloudregistryb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.cloudregistry.v1.artifact_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n!yandex.cloud.api.cloudregistry.v1ZOgithub.com/yandex-cloud/go-genproto/yandex/cloud/cloudregistry/v1;cloudregistry'
  _globals['_ARTIFACT']._serialized_start=113
  _globals['_ARTIFACT']._serialized_end=527
  _globals['_ARTIFACT_KIND']._serialized_start=386
  _globals['_ARTIFACT_KIND']._serialized_end=453
  _globals['_ARTIFACT_STATUS']._serialized_start=455
  _globals['_ARTIFACT_STATUS']._serialized_end=527
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import google.protobuf.wrappers_pb2
import typing
import yandex.cloud.ai.foundation_models.v1.batch_inference_task_status_pb2
import yandex.cloud.ai.foundation_models.v1.text_common_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class CompletionRequest(google.protobuf.message.Message):
    """Request for the service to generate text completion."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MODEL_URI_FIELD_NUMBER: builtins.int
    COMPLETION_OPTIONS_FIELD_NUMBER: builtins.int
    MESSAGES_FIELD_NUMBER: builtins.int
    TOOLS_FIELD_NUMBER: builtins.int
    JSON_OBJECT_FIELD_NUMBER: builtins.int
    JSON_SCHEMA_FIELD_NUMBER: builtins.int
    PARALLEL_TOOL_CALLS_FIELD_NUMBER: builtins.int
    TOOL_CHOICE_FIELD_NUMBER: builtins.int
    model_uri: builtins.str
    """The [ID of the model](/docs/foundation-models/concepts/yandexgpt/models) to be used for completion generation."""
    json_object: builtins.bool
    """When set to true, the model will respond with a valid JSON object.
    Be sure to explicitly ask the model for JSON.
    Otherwise, it may generate excessive whitespace and run indefinitely until it reaches the token limit.
    """
    @property
    def completion_options(self) -> yandex.cloud.ai.foundation_models.v1.text_common_pb2.CompletionOptions:
        """Configuration options for completion generation."""

    @property
    def messages(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.ai.foundation_models.v1.text_common_pb2.Message]:
        """A list of messages representing the context for the completion model."""

    @property
    def tools(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.ai.foundation_models.v1.text_common_pb2.Tool]:
        """List of tools that are available for the model to invoke during the completion generation.
        Note: This parameter is not yet supported and will be ignored if provided.
        """

    @property
    def json_schema(self) -> yandex.cloud.ai.foundation_models.v1.text_common_pb2.JsonSchema:
        """Enforces a specific JSON structure for the model's response based on a provided schema."""

    @property
    def parallel_tool_calls(self) -> google.protobuf.wrappers_pb2.BoolValue:
        """Controls whether the model can generate multiple tool calls in a single response. Defaults to true."""

    @property
    def tool_choice(self) -> yandex.cloud.ai.foundation_models.v1.text_common_pb2.ToolChoice:
        """Specifies how the model should select which tool (or tools) to use when generating a response."""

    def __init__(
        self,
        *,
        model_uri: builtins.str = ...,
        completion_options: yandex.cloud.ai.foundation_models.v1.text_common_pb2.CompletionOptions | None = ...,
        messages: collections.abc.Iterable[yandex.cloud.ai.foundation_models.v1.text_common_pb2.Message] | None = ...,
        tools: collections.abc.Iterable[yandex.cloud.ai.foundation_models.v1.text_common_pb2.Tool] | None = ...,
        json_object: builtins.bool = ...,
        json_schema: yandex.cloud.ai.foundation_models.v1.text_common_pb2.JsonSchema | None = ...,
        parallel_tool_calls: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        tool_choice: yandex.cloud.ai.foundation_models.v1.text_common_pb2.ToolChoice | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["ResponseFormat", b"ResponseFormat", "completion_options", b"completion_options", "json_object", b"json_object", "json_schema", b"json_schema", "parallel_tool_calls", b"parallel_tool_calls", "tool_choice", b"tool_choice"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["ResponseFormat", b"ResponseFormat", "completion_options", b"completion_options", "json_object", b"json_object", "json_schema", b"json_schema", "messages", b"messages", "model_uri", b"model_uri", "parallel_tool_calls", b"parallel_tool_calls", "tool_choice", b"tool_choice", "tools", b"tools"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["ResponseFormat", b"ResponseFormat"]) -> typing.Literal["json_object", "json_schema"] | None: ...

global___CompletionRequest = CompletionRequest

@typing.final
class CompletionResponse(google.protobuf.message.Message):
    """Response containing generated text completions."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ALTERNATIVES_FIELD_NUMBER: builtins.int
    USAGE_FIELD_NUMBER: builtins.int
    MODEL_VERSION_FIELD_NUMBER: builtins.int
    model_version: builtins.str
    """The model version changes with each new releases."""
    @property
    def alternatives(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.ai.foundation_models.v1.text_common_pb2.Alternative]:
        """A list of generated completion alternatives."""

    @property
    def usage(self) -> yandex.cloud.ai.foundation_models.v1.text_common_pb2.ContentUsage:
        """A set of statistics describing the number of content tokens used by the completion model."""

    def __init__(
        self,
        *,
        alternatives: collections.abc.Iterable[yandex.cloud.ai.foundation_models.v1.text_common_pb2.Alternative] | None = ...,
        usage: yandex.cloud.ai.foundation_models.v1.text_common_pb2.ContentUsage | None = ...,
        model_version: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["usage", b"usage"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["alternatives", b"alternatives", "model_version", b"model_version", "usage", b"usage"]) -> None: ...

global___CompletionResponse = CompletionResponse

@typing.final
class BatchCompletionRequest(google.protobuf.message.Message):
    """Request for the service to generate batch text completion."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MODEL_URI_FIELD_NUMBER: builtins.int
    COMPLETION_OPTIONS_FIELD_NUMBER: builtins.int
    SOURCE_DATASET_ID_FIELD_NUMBER: builtins.int
    JSON_OBJECT_FIELD_NUMBER: builtins.int
    JSON_SCHEMA_FIELD_NUMBER: builtins.int
    model_uri: builtins.str
    """The [ID of the model](/docs/foundation-models/concepts/yandexgpt/models) to be used for batch completion generation."""
    source_dataset_id: builtins.str
    """ID of the dataset containing the context for the completion model."""
    json_object: builtins.bool
    """When set to true, the model will respond with a valid JSON object.
    Be sure to explicitly ask the model for JSON.
    Otherwise, it may generate excessive whitespace and run indefinitely until it reaches the token limit.
    """
    @property
    def completion_options(self) -> yandex.cloud.ai.foundation_models.v1.text_common_pb2.CompletionOptions:
        """Configuration options for completion generation."""

    @property
    def json_schema(self) -> yandex.cloud.ai.foundation_models.v1.text_common_pb2.JsonSchema:
        """Enforces a specific JSON structure for the model's response based on a provided schema."""

    def __init__(
        self,
        *,
        model_uri: builtins.str = ...,
        completion_options: yandex.cloud.ai.foundation_models.v1.text_common_pb2.CompletionOptions | None = ...,
        source_dataset_id: builtins.str = ...,
        json_object: builtins.bool = ...,
        json_schema: yandex.cloud.ai.foundation_models.v1.text_common_pb2.JsonSchema | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["ResponseFormat", b"ResponseFormat", "completion_options", b"completion_options", "json_object", b"json_object", "json_schema", b"json_schema", "request_format", b"request_format", "source_dataset_id", b"source_dataset_id"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["ResponseFormat", b"ResponseFormat", "completion_options", b"completion_options", "json_object", b"json_object", "json_schema", b"json_schema", "model_uri", b"model_uri", "request_format", b"request_format", "source_dataset_id", b"source_dataset_id"]) -> None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["ResponseFormat", b"ResponseFormat"]) -> typing.Literal["json_object", "json_schema"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["request_format", b"request_format"]) -> typing.Literal["source_dataset_id"] | None: ...

global___BatchCompletionRequest = BatchCompletionRequest

@typing.final
class BatchCompletionMetadata(google.protobuf.message.Message):
    """Metadata of the batch completion operation."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_ID_FIELD_NUMBER: builtins.int
    TASK_STATUS_FIELD_NUMBER: builtins.int
    COMPLETED_BATCHES_FIELD_NUMBER: builtins.int
    TOTAL_BATCHES_FIELD_NUMBER: builtins.int
    task_id: builtins.str
    """The ID of the batch completion task."""
    task_status: yandex.cloud.ai.foundation_models.v1.batch_inference_task_status_pb2.BatchInferenceTaskStatus.ValueType
    """The status of the batch completion task."""
    completed_batches: builtins.int
    """A number of currently completed batches of the completion task."""
    total_batches: builtins.int
    """A number of total batches of the completion task."""
    def __init__(
        self,
        *,
        task_id: builtins.str = ...,
        task_status: yandex.cloud.ai.foundation_models.v1.batch_inference_task_status_pb2.BatchInferenceTaskStatus.ValueType = ...,
        completed_batches: builtins.int = ...,
        total_batches: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["completed_batches", b"completed_batches", "task_id", b"task_id", "task_status", b"task_status", "total_batches", b"total_batches"]) -> None: ...

global___BatchCompletionMetadata = BatchCompletionMetadata

@typing.final
class BatchCompletionResponse(google.protobuf.message.Message):
    """Response containing information about completion task."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_ID_FIELD_NUMBER: builtins.int
    TASK_STATUS_FIELD_NUMBER: builtins.int
    RESULT_DATASET_ID_FIELD_NUMBER: builtins.int
    task_id: builtins.str
    """The ID of the batch completion task."""
    task_status: yandex.cloud.ai.foundation_models.v1.batch_inference_task_status_pb2.BatchInferenceTaskStatus.ValueType
    """The status of the batch completion task."""
    result_dataset_id: builtins.str
    """The ID of the dataset containing completion results."""
    def __init__(
        self,
        *,
        task_id: builtins.str = ...,
        task_status: yandex.cloud.ai.foundation_models.v1.batch_inference_task_status_pb2.BatchInferenceTaskStatus.ValueType = ...,
        result_dataset_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["result_dataset_id", b"result_dataset_id", "task_id", b"task_id", "task_status", b"task_status"]) -> None: ...

global___BatchCompletionResponse = BatchCompletionResponse

@typing.final
class TokenizeRequest(google.protobuf.message.Message):
    """Request for the service to tokenize input text."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MODEL_URI_FIELD_NUMBER: builtins.int
    TEXT_FIELD_NUMBER: builtins.int
    model_uri: builtins.str
    """The identifier of the model to be used for tokenization."""
    text: builtins.str
    """Text to be tokenized."""
    def __init__(
        self,
        *,
        model_uri: builtins.str = ...,
        text: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["model_uri", b"model_uri", "text", b"text"]) -> None: ...

global___TokenizeRequest = TokenizeRequest

@typing.final
class TokenizeResponse(google.protobuf.message.Message):
    """Response containing tokenized content from request."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TOKENS_FIELD_NUMBER: builtins.int
    MODEL_VERSION_FIELD_NUMBER: builtins.int
    model_version: builtins.str
    """Model version (changes with model releases)."""
    @property
    def tokens(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.ai.foundation_models.v1.text_common_pb2.Token]:
        """A list of tokens obtained from tokenization."""

    def __init__(
        self,
        *,
        tokens: collections.abc.Iterable[yandex.cloud.ai.foundation_models.v1.text_common_pb2.Token] | None = ...,
        model_version: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["model_version", b"model_version", "tokens", b"tokens"]) -> None: ...

global___TokenizeResponse = TokenizeResponse



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.timestamp_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class Job(google.protobuf.message.Message):
    """A Yandex Data Processing job. For details about the concept, see [documentation](/docs/data-proc/concepts/jobs)."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _Status:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _StatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Job._Status.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        STATUS_UNSPECIFIED: Job._Status.ValueType  # 0
        PROVISIONING: Job._Status.ValueType  # 1
        """Job is logged in the database and is waiting for the agent to run it."""
        PENDING: Job._Status.ValueType  # 2
        """Job is acquired by the agent and is in the queue for execution."""
        RUNNING: Job._Status.ValueType  # 3
        """Job is being run in the cluster."""
        ERROR: Job._Status.ValueType  # 4
        """Job failed to finish the run properly."""
        DONE: Job._Status.ValueType  # 5
        """Job is finished."""
        CANCELLED: Job._Status.ValueType  # 6
        """Job is cancelled."""
        CANCELLING: Job._Status.ValueType  # 7
        """Job is waiting for cancellation."""

    class Status(_Status, metaclass=_StatusEnumTypeWrapper): ...
    STATUS_UNSPECIFIED: Job.Status.ValueType  # 0
    PROVISIONING: Job.Status.ValueType  # 1
    """Job is logged in the database and is waiting for the agent to run it."""
    PENDING: Job.Status.ValueType  # 2
    """Job is acquired by the agent and is in the queue for execution."""
    RUNNING: Job.Status.ValueType  # 3
    """Job is being run in the cluster."""
    ERROR: Job.Status.ValueType  # 4
    """Job failed to finish the run properly."""
    DONE: Job.Status.ValueType  # 5
    """Job is finished."""
    CANCELLED: Job.Status.ValueType  # 6
    """Job is cancelled."""
    CANCELLING: Job.Status.ValueType  # 7
    """Job is waiting for cancellation."""

    ID_FIELD_NUMBER: builtins.int
    CLUSTER_ID_FIELD_NUMBER: builtins.int
    CREATED_AT_FIELD_NUMBER: builtins.int
    STARTED_AT_FIELD_NUMBER: builtins.int
    FINISHED_AT_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    CREATED_BY_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    MAPREDUCE_JOB_FIELD_NUMBER: builtins.int
    SPARK_JOB_FIELD_NUMBER: builtins.int
    PYSPARK_JOB_FIELD_NUMBER: builtins.int
    HIVE_JOB_FIELD_NUMBER: builtins.int
    APPLICATION_INFO_FIELD_NUMBER: builtins.int
    id: builtins.str
    """ID of the job. Generated at creation time."""
    cluster_id: builtins.str
    """ID of the Yandex Data Processing cluster that the job belongs to."""
    name: builtins.str
    """Name of the job, specified in the [JobService.Create] request."""
    created_by: builtins.str
    """The id of the user who created the job"""
    status: global___Job.Status.ValueType
    """Job status."""
    @property
    def created_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Creation timestamp."""

    @property
    def started_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """The time when the job was started."""

    @property
    def finished_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """The time when the job was finished."""

    @property
    def mapreduce_job(self) -> global___MapreduceJob:
        """Specification for a MapReduce job."""

    @property
    def spark_job(self) -> global___SparkJob:
        """Specification for a Spark job."""

    @property
    def pyspark_job(self) -> global___PysparkJob:
        """Specification for a PySpark job."""

    @property
    def hive_job(self) -> global___HiveJob:
        """Specification for a Hive job."""

    @property
    def application_info(self) -> global___ApplicationInfo:
        """Attributes of YARN application."""

    def __init__(
        self,
        *,
        id: builtins.str = ...,
        cluster_id: builtins.str = ...,
        created_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        started_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        finished_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        name: builtins.str = ...,
        created_by: builtins.str = ...,
        status: global___Job.Status.ValueType = ...,
        mapreduce_job: global___MapreduceJob | None = ...,
        spark_job: global___SparkJob | None = ...,
        pyspark_job: global___PysparkJob | None = ...,
        hive_job: global___HiveJob | None = ...,
        application_info: global___ApplicationInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["application_info", b"application_info", "created_at", b"created_at", "finished_at", b"finished_at", "hive_job", b"hive_job", "job_spec", b"job_spec", "mapreduce_job", b"mapreduce_job", "pyspark_job", b"pyspark_job", "spark_job", b"spark_job", "started_at", b"started_at"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["application_info", b"application_info", "cluster_id", b"cluster_id", "created_at", b"created_at", "created_by", b"created_by", "finished_at", b"finished_at", "hive_job", b"hive_job", "id", b"id", "job_spec", b"job_spec", "mapreduce_job", b"mapreduce_job", "name", b"name", "pyspark_job", b"pyspark_job", "spark_job", b"spark_job", "started_at", b"started_at", "status", b"status"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["job_spec", b"job_spec"]) -> typing.Literal["mapreduce_job", "spark_job", "pyspark_job", "hive_job"] | None: ...

global___Job = Job

@typing.final
class ApplicationAttempt(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    AM_CONTAINER_ID_FIELD_NUMBER: builtins.int
    id: builtins.str
    """ID of YARN application attempt"""
    am_container_id: builtins.str
    """ID of YARN Application Master container"""
    def __init__(
        self,
        *,
        id: builtins.str = ...,
        am_container_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["am_container_id", b"am_container_id", "id", b"id"]) -> None: ...

global___ApplicationAttempt = ApplicationAttempt

@typing.final
class ApplicationInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    APPLICATION_ATTEMPTS_FIELD_NUMBER: builtins.int
    id: builtins.str
    """ID of YARN application"""
    @property
    def application_attempts(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ApplicationAttempt]:
        """YARN application attempts"""

    def __init__(
        self,
        *,
        id: builtins.str = ...,
        application_attempts: collections.abc.Iterable[global___ApplicationAttempt] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["application_attempts", b"application_attempts", "id", b"id"]) -> None: ...

global___ApplicationInfo = ApplicationInfo

@typing.final
class MapreduceJob(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class PropertiesEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    ARGS_FIELD_NUMBER: builtins.int
    JAR_FILE_URIS_FIELD_NUMBER: builtins.int
    FILE_URIS_FIELD_NUMBER: builtins.int
    ARCHIVE_URIS_FIELD_NUMBER: builtins.int
    PROPERTIES_FIELD_NUMBER: builtins.int
    MAIN_JAR_FILE_URI_FIELD_NUMBER: builtins.int
    MAIN_CLASS_FIELD_NUMBER: builtins.int
    main_jar_file_uri: builtins.str
    """HCFS URI of the .jar file containing the driver class."""
    main_class: builtins.str
    """The name of the driver class."""
    @property
    def args(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """Optional arguments to pass to the driver."""

    @property
    def jar_file_uris(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """JAR file URIs to add to CLASSPATH of the Yandex Data Processing driver and each task."""

    @property
    def file_uris(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """URIs of resource files to be copied to the working directory of Yandex Data Processing drivers
        and distributed Hadoop tasks.
        """

    @property
    def archive_uris(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """URIs of archives to be extracted to the working directory of Yandex Data Processing drivers and tasks."""

    @property
    def properties(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Property names and values, used to configure Yandex Data Processing and MapReduce."""

    def __init__(
        self,
        *,
        args: collections.abc.Iterable[builtins.str] | None = ...,
        jar_file_uris: collections.abc.Iterable[builtins.str] | None = ...,
        file_uris: collections.abc.Iterable[builtins.str] | None = ...,
        archive_uris: collections.abc.Iterable[builtins.str] | None = ...,
        properties: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        main_jar_file_uri: builtins.str = ...,
        main_class: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["driver", b"driver", "main_class", b"main_class", "main_jar_file_uri", b"main_jar_file_uri"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["archive_uris", b"archive_uris", "args", b"args", "driver", b"driver", "file_uris", b"file_uris", "jar_file_uris", b"jar_file_uris", "main_class", b"main_class", "main_jar_file_uri", b"main_jar_file_uri", "properties", b"properties"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["driver", b"driver"]) -> typing.Literal["main_jar_file_uri", "main_class"] | None: ...

global___MapreduceJob = MapreduceJob

@typing.final
class SparkJob(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class PropertiesEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    ARGS_FIELD_NUMBER: builtins.int
    JAR_FILE_URIS_FIELD_NUMBER: builtins.int
    FILE_URIS_FIELD_NUMBER: builtins.int
    ARCHIVE_URIS_FIELD_NUMBER: builtins.int
    PROPERTIES_FIELD_NUMBER: builtins.int
    MAIN_JAR_FILE_URI_FIELD_NUMBER: builtins.int
    MAIN_CLASS_FIELD_NUMBER: builtins.int
    PACKAGES_FIELD_NUMBER: builtins.int
    REPOSITORIES_FIELD_NUMBER: builtins.int
    EXCLUDE_PACKAGES_FIELD_NUMBER: builtins.int
    main_jar_file_uri: builtins.str
    """The HCFS URI of the JAR file containing the `main` class for the job."""
    main_class: builtins.str
    """The name of the driver class."""
    @property
    def args(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """Optional arguments to pass to the driver."""

    @property
    def jar_file_uris(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """JAR file URIs to add to CLASSPATH of the Yandex Data Processing driver and each task."""

    @property
    def file_uris(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """URIs of resource files to be copied to the working directory of Yandex Data Processing drivers
        and distributed Hadoop tasks.
        """

    @property
    def archive_uris(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """URIs of archives to be extracted to the working directory of Yandex Data Processing drivers and tasks."""

    @property
    def properties(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Property names and values, used to configure Yandex Data Processing and Spark."""

    @property
    def packages(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """List of maven coordinates of jars to include on the driver and executor classpaths."""

    @property
    def repositories(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """List of additional remote repositories to search for the maven coordinates given with --packages."""

    @property
    def exclude_packages(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """List of groupId:artifactId, to exclude while resolving the dependencies provided in --packages to avoid dependency conflicts."""

    def __init__(
        self,
        *,
        args: collections.abc.Iterable[builtins.str] | None = ...,
        jar_file_uris: collections.abc.Iterable[builtins.str] | None = ...,
        file_uris: collections.abc.Iterable[builtins.str] | None = ...,
        archive_uris: collections.abc.Iterable[builtins.str] | None = ...,
        properties: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        main_jar_file_uri: builtins.str = ...,
        main_class: builtins.str = ...,
        packages: collections.abc.Iterable[builtins.str] | None = ...,
        repositories: collections.abc.Iterable[builtins.str] | None = ...,
        exclude_packages: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["archive_uris", b"archive_uris", "args", b"args", "exclude_packages", b"exclude_packages", "file_uris", b"file_uris", "jar_file_uris", b"jar_file_uris", "main_class", b"main_class", "main_jar_file_uri", b"main_jar_file_uri", "packages", b"packages", "properties", b"properties", "repositories", b"repositories"]) -> None: ...

global___SparkJob = SparkJob

@typing.final
class PysparkJob(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class PropertiesEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    ARGS_FIELD_NUMBER: builtins.int
    JAR_FILE_URIS_FIELD_NUMBER: builtins.int
    FILE_URIS_FIELD_NUMBER: builtins.int
    ARCHIVE_URIS_FIELD_NUMBER: builtins.int
    PROPERTIES_FIELD_NUMBER: builtins.int
    MAIN_PYTHON_FILE_URI_FIELD_NUMBER: builtins.int
    PYTHON_FILE_URIS_FIELD_NUMBER: builtins.int
    PACKAGES_FIELD_NUMBER: builtins.int
    REPOSITORIES_FIELD_NUMBER: builtins.int
    EXCLUDE_PACKAGES_FIELD_NUMBER: builtins.int
    main_python_file_uri: builtins.str
    """URI of the file with the driver code. Must be a .py file."""
    @property
    def args(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """Optional arguments to pass to the driver."""

    @property
    def jar_file_uris(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """JAR file URIs to add to CLASSPATH of the Yandex Data Processing driver and each task."""

    @property
    def file_uris(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """URIs of resource files to be copied to the working directory of Yandex Data Processing drivers
        and distributed Hadoop tasks.
        """

    @property
    def archive_uris(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """URIs of archives to be extracted to the working directory of Yandex Data Processing drivers and tasks."""

    @property
    def properties(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Property names and values, used to configure Yandex Data Processing and PySpark."""

    @property
    def python_file_uris(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """URIs of Python files to pass to the PySpark framework."""

    @property
    def packages(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """List of maven coordinates of jars to include on the driver and executor classpaths."""

    @property
    def repositories(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """List of additional remote repositories to search for the maven coordinates given with --packages."""

    @property
    def exclude_packages(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """List of groupId:artifactId, to exclude while resolving the dependencies provided in --packages to avoid dependency conflicts."""

    def __init__(
        self,
        *,
        args: collections.abc.Iterable[builtins.str] | None = ...,
        jar_file_uris: collections.abc.Iterable[builtins.str] | None = ...,
        file_uris: collections.abc.Iterable[builtins.str] | None = ...,
        archive_uris: collections.abc.Iterable[builtins.str] | None = ...,
        properties: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        main_python_file_uri: builtins.str = ...,
        python_file_uris: collections.abc.Iterable[builtins.str] | None = ...,
        packages: collections.abc.Iterable[builtins.str] | None = ...,
        repositories: collections.abc.Iterable[builtins.str] | None = ...,
        exclude_packages: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["archive_uris", b"archive_uris", "args", b"args", "exclude_packages", b"exclude_packages", "file_uris", b"file_uris", "jar_file_uris", b"jar_file_uris", "main_python_file_uri", b"main_python_file_uri", "packages", b"packages", "properties", b"properties", "python_file_uris", b"python_file_uris", "repositories", b"repositories"]) -> None: ...

global___PysparkJob = PysparkJob

@typing.final
class QueryList(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    QUERIES_FIELD_NUMBER: builtins.int
    @property
    def queries(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """List of Hive queries."""

    def __init__(
        self,
        *,
        queries: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["queries", b"queries"]) -> None: ...

global___QueryList = QueryList

@typing.final
class HiveJob(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class PropertiesEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    @typing.final
    class ScriptVariablesEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    PROPERTIES_FIELD_NUMBER: builtins.int
    CONTINUE_ON_FAILURE_FIELD_NUMBER: builtins.int
    SCRIPT_VARIABLES_FIELD_NUMBER: builtins.int
    JAR_FILE_URIS_FIELD_NUMBER: builtins.int
    QUERY_FILE_URI_FIELD_NUMBER: builtins.int
    QUERY_LIST_FIELD_NUMBER: builtins.int
    continue_on_failure: builtins.bool
    """Flag indicating whether a job should continue to run if a query fails."""
    query_file_uri: builtins.str
    """URI of the script with all the necessary Hive queries."""
    @property
    def properties(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Property names and values, used to configure Yandex Data Processing and Hive."""

    @property
    def script_variables(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Query variables and their values."""

    @property
    def jar_file_uris(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """JAR file URIs to add to CLASSPATH of the Hive driver and each task."""

    @property
    def query_list(self) -> global___QueryList:
        """List of Hive queries to be used in the job."""

    def __init__(
        self,
        *,
        properties: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        continue_on_failure: builtins.bool = ...,
        script_variables: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        jar_file_uris: collections.abc.Iterable[builtins.str] | None = ...,
        query_file_uri: builtins.str = ...,
        query_list: global___QueryList | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["query_file_uri", b"query_file_uri", "query_list", b"query_list", "query_type", b"query_type"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["continue_on_failure", b"continue_on_failure", "jar_file_uris", b"jar_file_uris", "properties", b"properties", "query_file_uri", b"query_file_uri", "query_list", b"query_list", "query_type", b"query_type", "script_variables", b"script_variables"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["query_type", b"query_type"]) -> typing.Literal["query_file_uri", "query_list"] | None: ...

global___HiveJob = HiveJob



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class ShieldingDetails(google.protobuf.message.Message):
    """Message representing the details of a shielding server."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LOCATION_ID_FIELD_NUMBER: builtins.int
    DATA_CENTER_FIELD_NUMBER: builtins.int
    COUNTRY_FIELD_NUMBER: builtins.int
    CITY_FIELD_NUMBER: builtins.int
    location_id: builtins.int
    """Unique identifier for the geographical location of the shielding server."""
    data_center: builtins.str
    """Name of the data center where the shielding server is located."""
    country: builtins.str
    """Country where the shielding server's data center is located, useful for understanding geographical distribution."""
    city: builtins.str
    """City where the shielding server's data center is situated, providing a more precise location than just the country."""
    def __init__(
        self,
        *,
        location_id: builtins.int = ...,
        data_center: builtins.str = ...,
        country: builtins.str = ...,
        city: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["city", b"city", "country", b"country", "data_center", b"data_center", "location_id", b"location_id"]) -> None: ...

global___ShieldingDetails = ShieldingDetails
